==> tine20-voip_2019.12.5.tar.bz2: Phone/js/Phone-lang-pl-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Phone **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Phone'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-09-28 09:49+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Polish (http://www.transifex.com/tine20/tine20/language/pl/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: pl\nPlural-Forms: nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Call"
: ""

, "Calls"
: ""

, "Line"
: "Łącze"

, "Caller Id"
: "Własny numer telefonu"

, "Start"
: "Początek połączenia"

, "Connected"
: "Połączony"

, "Disconnected"
: "Rozłączony"

, "Duration"
: "Czas połączenia"

, "Ringing"
: "Dzwoni"

, "Direction"
: "Kierunkowy"

, "Source"
: "Źródło"

, "Destination"
: "Rozmówca"

, "Phone"
: ""

, "Phones"
: "Telefony"

, "Settings"
: ""

, "Lines"
: ""

, "Description"
: ""

, "Number"
: "Numer"

, "Cancel"
: "Anuluj"

, "Dial"
: "Połącz"

, "Error"
: "Błąd"

, "Not possible to dial."
: "Nie można nawiązać połączenia."

, "Edit phone settings"
: "Edytuj ustawienia telefonu"

, "Dial number"
: "Wybierz numer"

, "Initiate a new outgoing call"
: "Zestaw nowe połączenie wychodzące"

, "No phone selected"
: ""

, "Please select the desired phone in the tree!"
: ""

, "Call contact"
: "Wywołaj kontakt"

, "Work"
: "Praca"

, "Home"
: "Dom"

, "Cell"
: "Komórka"

, "Cell private"
: "Prywatna komórka"

, "Incoming call"
: "Połączenie przychodzące"

, "Outgoing call"
: "Połączenie wychodzące"

, "unknown number"
: "nieznany numer"

, "local prefix for outgoing calls"
: ""

, "telephone area code"
: ""

, "regex for local calls"
: ""

, "identifies if a calling number is a local call without leading area code"
: ""

, "own telephone number"
: ""

, "own telephone number to prefix to internal calls"
: ""

, "Calls this week"
: ""

, "Incoming and outgoing calls of this week"
: ""

, "Calls last week"
: ""

, "Incoming and outgoing calls of last week"
: ""

, "Calls this month"
: ""

, "Incoming and outgoing calls of this month"
: ""

, "Calls last month"
: ""

, "Incoming and outgoing calls of last month"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-voip_2020.03.4.tar.bz2: Phone/js/Phone-lang-pl-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Phone **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Phone'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-09-28 09:49+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Polish (http://www.transifex.com/tine20/tine20/language/pl/)\nLanguage: pl\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Incoming call"
: "Połączenie przychodzące"

, "Outgoing call"
: "Połączenie wychodzące"

, "unknown number"
: "nieznany numer"

, "Phone"
: ""

, "Line"
: "Łącze"

, "Number"
: "Numer"

, "Cancel"
: "Anuluj"

, "Dial"
: "Połącz"

, "Error"
: "Błąd"

, "Not possible to dial."
: "Nie można nawiązać połączenia."

, "Call contact"
: "Wywołaj kontakt"

, "Work"
: "Praca"

, "Home"
: "Dom"

, "Cell"
: "Komórka"

, "Cell private"
: "Prywatna komórka"

, "Edit phone settings"
: "Edytuj ustawienia telefonu"

, "Dial number"
: "Wybierz numer"

, "Initiate a new outgoing call"
: "Zestaw nowe połączenie wychodzące"

, "Phones"
: "Telefony"

, "No phone selected"
: ""

, "Please select the desired phone in the tree!"
: ""

, "Calls this week"
: ""

, "Calls last week"
: ""

, "Calls this month"
: ""

, "Calls last month"
: ""

, "Incoming and outgoing calls of this week"
: ""

, "Incoming and outgoing calls of last week"
: ""

, "Incoming and outgoing calls of this month"
: ""

, "Incoming and outgoing calls of last month"
: ""

, "Local prefix for outgoing calls"
: ""

, "telephone area code"
: ""

, "regex for local calls"
: ""

, "Identifies if a calling number is a local call without leading area code."
: ""

, "own telephone number"
: ""

, "Own telephone number to prefix to internal calls."
: ""

, "Call"
: ""

, "Calls"
: ""

, "Caller Id"
: "Własny numer telefonu"

, "Start"
: "Początek połączenia"

, "Connected"
: "Połączony"

, "Disconnected"
: "Rozłączony"

, "Duration"
: "Czas połączenia"

, "Ringing"
: "Dzwoni"

, "Direction"
: "Kierunkowy"

, "Source"
: "Źródło"

, "Destination"
: "Rozmówca"

, "resolved destination"
: ""

, "Settings"
: ""

, "Lines"
: ""

, "Description"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
